@@ -1,6 +1,7 @@
 MSLT.e <-
-function (S,radix)
-{ 	nage <- nrow(S)
+function (SS,radix)
+{ 	S<-SS$S
+	nage <- nrow(S)
    iradix <- which(radix>0)
    lt <- apply(S[,,iradix],1,sum) # total survival prob: starts in iradix (1)
     namstates <- unlist(unname(dimnames(S)[2]))
@@ -18,11 +19,22 @@ function (S,radix)
     e.p <- array(NA,dim=c(nage,numstates,numstates),dimnames=dimnames(S))
     e.s <- e.p
     for (ix in 1:(nage-1))
-    {  e.p[ix,,] <- apply (LL[ix:nage,,],c(2,3),sum)/lt[ix]
-       zx <- det(S[ix,,])
-       if (zx < 1e-16) {e.s[ix,,] <- NA} else
-         {e.s[ix,,] <- apply (LL[ix:nage,,],c(2,3),sum)%*%solve(S[ix,,])}
+    {  e.p[ix,,] <- apply (LL[ix:nage,,],c(2,3),sum)/lt[ix]}
+    
+    LLL <- LL
+    for (ix in 1:(nage-1))
+    { S[ix,,] <- 0 
+      diag(S[ix,,]) <- 1
+      for (iy in ix:(nage-1))
+      {  S[iy+1,,] <- SS$P[iy,,]%*%S[iy,,]
+      	 LLL[iy,,] <- 0.5 * (S[iy,,]+S[iy+1,,])
+      }
+      e.s[ix,,] <- apply(LLL[ix:nage,,],c(2,3),sum)
     }
+     #  zx <- det(S[ix,,])
+     #  if (zx < 1e-16) {e.s[ix,,] <- NA} else
+     #    {e.s[ix,,] <- apply (LL[ix:nage,,],c(2,3),sum)%*%solve(S[ix,,])}
+    
   return (list(L = LL,
                e0=e0, 
                e.p = e.p,
